@@ -25,38 +25,34 @@ class DescribeAccesskeyLeakListRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeAccesskeyLeakList')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Query(self):
+	def get_Query(self): # String
 		return self.get_query_params().get('Query')
 
-	def set_Query(self,Query):
-		self.add_query_param('Query',Query)
-
-	def get_StartTs(self):
+	def set_Query(self, Query):  # String
+		self.add_query_param('Query', Query)
+	def get_StartTs(self): # Long
 		return self.get_query_params().get('StartTs')
 
-	def set_StartTs(self,StartTs):
-		self.add_query_param('StartTs',StartTs)
-
-	def get_CurrentPage(self):
+	def set_StartTs(self, StartTs):  # Long
+		self.add_query_param('StartTs', StartTs)
+	def get_CurrentPage(self): # Integer
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
-	def get_PageSize(self):
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_Status(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_Status(self): # String
 		return self.get_query_params().get('Status')
 
-	def set_Status(self,Status):
-		self.add_query_param('Status',Status)
\ No newline at end of file
+	def set_Status(self, Status):  # String
+		self.add_query_param('Status', Status)
