@@ -25,26 +25,24 @@ class DescribeCriteriaRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeCriteria')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SupportAutoTag(self):
+	def get_SupportAutoTag(self): # Boolean
 		return self.get_query_params().get('SupportAutoTag')
 
-	def set_SupportAutoTag(self,SupportAutoTag):
-		self.add_query_param('SupportAutoTag',SupportAutoTag)
-
-	def get_Value(self):
+	def set_SupportAutoTag(self, SupportAutoTag):  # Boolean
+		self.add_query_param('SupportAutoTag', SupportAutoTag)
+	def get_Value(self): # String
 		return self.get_query_params().get('Value')
 
-	def set_Value(self,Value):
-		self.add_query_param('Value',Value)
-
-	def get_MachineTypes(self):
+	def set_Value(self, Value):  # String
+		self.add_query_param('Value', Value)
+	def get_MachineTypes(self): # String
 		return self.get_query_params().get('MachineTypes')
 
-	def set_MachineTypes(self,MachineTypes):
-		self.add_query_param('MachineTypes',MachineTypes)
\ No newline at end of file
+	def set_MachineTypes(self, MachineTypes):  # String
+		self.add_query_param('MachineTypes', MachineTypes)
