@@ -25,38 +25,34 @@ class DescribeDomainListRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeDomainList')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_CurrentPage(self):
+	def get_CurrentPage(self): # Integer
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
-	def get_FuzzyDomain(self):
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
+	def get_FuzzyDomain(self): # String
 		return self.get_query_params().get('FuzzyDomain')
 
-	def set_FuzzyDomain(self,FuzzyDomain):
-		self.add_query_param('FuzzyDomain',FuzzyDomain)
-
-	def get_SourceIp(self):
+	def set_FuzzyDomain(self, FuzzyDomain):  # String
+		self.add_query_param('FuzzyDomain', FuzzyDomain)
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_DomainType(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_DomainType(self): # String
 		return self.get_query_params().get('DomainType')
 
-	def set_DomainType(self,DomainType):
-		self.add_query_param('DomainType',DomainType)
-
-	def get_PageSize(self):
+	def set_DomainType(self, DomainType):  # String
+		self.add_query_param('DomainType', DomainType)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
