@@ -25,64 +25,55 @@ class ModifyAntiBruteForceRuleRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ModifyAntiBruteForceRule')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ForbiddenTime(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ForbiddenTime(self): # Integer
 		return self.get_query_params().get('ForbiddenTime')
 
-	def set_ForbiddenTime(self,ForbiddenTime):
-		self.add_query_param('ForbiddenTime',ForbiddenTime)
-
-	def get_FailCount(self):
+	def set_ForbiddenTime(self, ForbiddenTime):  # Integer
+		self.add_query_param('ForbiddenTime', ForbiddenTime)
+	def get_FailCount(self): # Integer
 		return self.get_query_params().get('FailCount')
 
-	def set_FailCount(self,FailCount):
-		self.add_query_param('FailCount',FailCount)
-
-	def get_SourceIp(self):
+	def set_FailCount(self, FailCount):  # Integer
+		self.add_query_param('FailCount', FailCount)
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_UuidLists(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_UuidLists(self): # RepeatList
 		return self.get_query_params().get('UuidList')
 
-	def set_UuidLists(self, UuidLists):
-		for depth1 in range(len(UuidLists)):
-			if UuidLists[depth1] is not None:
-				self.add_query_param('UuidList.' + str(depth1 + 1) , UuidLists[depth1])
-
-	def get_Id(self):
+	def set_UuidLists(self, UuidList):  # RepeatList
+		for depth1 in range(len(UuidList)):
+			self.add_query_param('UuidList.' + str(depth1 + 1), UuidList[depth1])
+	def get_Id(self): # Long
 		return self.get_query_params().get('Id')
 
-	def set_Id(self,Id):
-		self.add_query_param('Id',Id)
-
-	def get_Name(self):
+	def set_Id(self, Id):  # Long
+		self.add_query_param('Id', Id)
+	def get_Name(self): # String
 		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
-
-	def get_Span(self):
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
+	def get_Span(self): # Integer
 		return self.get_query_params().get('Span')
 
-	def set_Span(self,Span):
-		self.add_query_param('Span',Span)
-
-	def get_DefaultRule(self):
+	def set_Span(self, Span):  # Integer
+		self.add_query_param('Span', Span)
+	def get_DefaultRule(self): # Boolean
 		return self.get_query_params().get('DefaultRule')
 
-	def set_DefaultRule(self,DefaultRule):
-		self.add_query_param('DefaultRule',DefaultRule)
\ No newline at end of file
+	def set_DefaultRule(self, DefaultRule):  # Boolean
+		self.add_query_param('DefaultRule', DefaultRule)
