@@ -25,86 +25,74 @@ class ModifyWebLockUpdateConfigRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ModifyWebLockUpdateConfig')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_LocalBackupDir(self):
+	def get_LocalBackupDir(self): # String
 		return self.get_query_params().get('LocalBackupDir')
 
-	def set_LocalBackupDir(self,LocalBackupDir):
-		self.add_query_param('LocalBackupDir',LocalBackupDir)
-
-	def get_ExclusiveFile(self):
+	def set_LocalBackupDir(self, LocalBackupDir):  # String
+		self.add_query_param('LocalBackupDir', LocalBackupDir)
+	def get_ExclusiveFile(self): # String
 		return self.get_query_params().get('ExclusiveFile')
 
-	def set_ExclusiveFile(self,ExclusiveFile):
-		self.add_query_param('ExclusiveFile',ExclusiveFile)
-
-	def get_ExclusiveFileType(self):
+	def set_ExclusiveFile(self, ExclusiveFile):  # String
+		self.add_query_param('ExclusiveFile', ExclusiveFile)
+	def get_ExclusiveFileType(self): # String
 		return self.get_query_params().get('ExclusiveFileType')
 
-	def set_ExclusiveFileType(self,ExclusiveFileType):
-		self.add_query_param('ExclusiveFileType',ExclusiveFileType)
-
-	def get_Dir(self):
+	def set_ExclusiveFileType(self, ExclusiveFileType):  # String
+		self.add_query_param('ExclusiveFileType', ExclusiveFileType)
+	def get_Dir(self): # String
 		return self.get_query_params().get('Dir')
 
-	def set_Dir(self,Dir):
-		self.add_query_param('Dir',Dir)
-
-	def get_Uuid(self):
+	def set_Dir(self, Dir):  # String
+		self.add_query_param('Dir', Dir)
+	def get_Uuid(self): # String
 		return self.get_query_params().get('Uuid')
 
-	def set_Uuid(self,Uuid):
-		self.add_query_param('Uuid',Uuid)
-
-	def get_Mode(self):
+	def set_Uuid(self, Uuid):  # String
+		self.add_query_param('Uuid', Uuid)
+	def get_Mode(self): # String
 		return self.get_query_params().get('Mode')
 
-	def set_Mode(self,Mode):
-		self.add_query_param('Mode',Mode)
-
-	def get_SourceIp(self):
+	def set_Mode(self, Mode):  # String
+		self.add_query_param('Mode', Mode)
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_Id(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_Id(self): # Integer
 		return self.get_query_params().get('Id')
 
-	def set_Id(self,Id):
-		self.add_query_param('Id',Id)
-
-	def get_Lang(self):
+	def set_Id(self, Id):  # Integer
+		self.add_query_param('Id', Id)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_InclusiveFile(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_InclusiveFile(self): # String
 		return self.get_query_params().get('InclusiveFile')
 
-	def set_InclusiveFile(self,InclusiveFile):
-		self.add_query_param('InclusiveFile',InclusiveFile)
-
-	def get_ExclusiveDir(self):
+	def set_InclusiveFile(self, InclusiveFile):  # String
+		self.add_query_param('InclusiveFile', InclusiveFile)
+	def get_ExclusiveDir(self): # String
 		return self.get_query_params().get('ExclusiveDir')
 
-	def set_ExclusiveDir(self,ExclusiveDir):
-		self.add_query_param('ExclusiveDir',ExclusiveDir)
-
-	def get_InclusiveFileType(self):
+	def set_ExclusiveDir(self, ExclusiveDir):  # String
+		self.add_query_param('ExclusiveDir', ExclusiveDir)
+	def get_InclusiveFileType(self): # String
 		return self.get_query_params().get('InclusiveFileType')
 
-	def set_InclusiveFileType(self,InclusiveFileType):
-		self.add_query_param('InclusiveFileType',InclusiveFileType)
-
-	def get_DefenceMode(self):
+	def set_InclusiveFileType(self, InclusiveFileType):  # String
+		self.add_query_param('InclusiveFileType', InclusiveFileType)
+	def get_DefenceMode(self): # String
 		return self.get_query_params().get('DefenceMode')
 
-	def set_DefenceMode(self,DefenceMode):
-		self.add_query_param('DefenceMode',DefenceMode)
\ No newline at end of file
+	def set_DefenceMode(self, DefenceMode):  # String
+		self.add_query_param('DefenceMode', DefenceMode)
