@@ -25,38 +25,34 @@ class OperateSuspiciousTargetConfigRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'OperateSuspiciousTargetConfig')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_TargetType(self):
+	def get_TargetType(self): # String
 		return self.get_query_params().get('TargetType')
 
-	def set_TargetType(self,TargetType):
-		self.add_query_param('TargetType',TargetType)
-
-	def get_Type(self):
+	def set_TargetType(self, TargetType):  # String
+		self.add_query_param('TargetType', TargetType)
+	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
-	def set_Type(self,Type):
-		self.add_query_param('Type',Type)
-
-	def get_TargetOperations(self):
+	def set_Type(self, Type):  # String
+		self.add_query_param('Type', Type)
+	def get_TargetOperations(self): # String
 		return self.get_query_params().get('TargetOperations')
 
-	def set_TargetOperations(self,TargetOperations):
-		self.add_query_param('TargetOperations',TargetOperations)
-
-	def get_SourceIp(self):
+	def set_TargetOperations(self, TargetOperations):  # String
+		self.add_query_param('TargetOperations', TargetOperations)
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_Lang(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
